BEGIN;

CREATE TABLE reader_streams (

	"id" TEXT PRIMARY KEY,
	"type" TEXT,
	"title" TEXT,
	"link" TEXT,
	"unreadCount" INTEGER DEFAULT 0,
	"starredCount" INTEGER DEFAULT 0,
	"visible" INTEGER DEFAULT 0,
	"index" REAL,
	
	"following" INTEGER DEFAULT 0,
	
	"feeds_string" TEXT,
	"folders_string" TEXT
	
);


CREATE TABLE reader_items (

	"id" TEXT PRIMARY KEY,

	"unread" INTEGER,
	"published" INTEGER,
	"day" TEXT,

	"starred" INTEGER,
	"publishedStarred" INTEGER,
	"dayStarred" TEXT,

	"shared" INTEGER,
	"publishedShared"	INTEGER,
	"dayShared" TEXT,

	"note" INTEGER,

	"cached" INTEGER DEFAULT 0,

	"deleted" INTEGER,
	
	"liked" INTEGER DEFAULT 0,

	"title" TEXT,
	"link" TEXT,
	"summary" TEXT,

	"stream_id" TEXT,
	
	"shared_by" TEXT

);

CREATE INDEX reader_feeds_visible ON reader_streams ("visible");
CREATE INDEX reader_items_unread ON reader_items ("unread");
CREATE INDEX reader_items_starred ON reader_items ("starred");
CREATE INDEX reader_items_shared ON reader_items ("shared");
CREATE INDEX reader_items_note ON reader_items ("note");
CREATE INDEX reader_items_deleted ON reader_items ("deleted");
CREATE INDEX reader_items_stream ON reader_items ("stream_id");


CREATE TRIGGER reader_streams_count_inc AFTER INSERT ON reader_items
BEGIN
	UPDATE reader_streams SET unreadCount=unreadCount+NEW.unread, starredCount=starredCount+NEW.starred WHERE id=NEW.stream_id;
END;

CREATE TRIGGER reader_streams_unreadCount_inc AFTER UPDATE OF unread ON reader_items
	WHEN NEW.unread=1 AND OLD.unread!=1
	BEGIN
		UPDATE reader_streams SET unreadCount=unreadCount+1 WHERE id=NEW.stream_id;
	END;

CREATE TRIGGER reader_streams_unreadCount_dec AFTER UPDATE OF unread ON reader_items
	WHEN NEW.unread!=1 AND OLD.unread=1
	BEGIN
		UPDATE reader_streams SET unreadCount=unreadCount-1 WHERE id=NEW.stream_id;
	END;

CREATE TRIGGER reader_streams_starredCount_inc AFTER UPDATE OF starred ON reader_items
	WHEN NEW.starred=1 AND OLD.starred!=1
	BEGIN
		UPDATE reader_streams SET starredCount=starredCount+1 WHERE id=NEW.stream_id;
	END;

CREATE TRIGGER reader_streams_starredCount_dec AFTER UPDATE OF starred ON reader_items
	WHEN NEW.starred!=1 AND OLD.starred=1
	BEGIN
		UPDATE reader_streams SET starredCount=starredCount-1 WHERE id=NEW.stream_id;
	END;


COMMIT;